==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/coordination/v1/LeaseOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.coordination.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.coordination.v1.DoneableLease;
import io.fabric8.kubernetes.api.model.coordination.v1.Lease;
import io.fabric8.kubernetes.api.model.coordination.v1.LeaseList;
import io.fabric8.kubernetes.api.model.coordination.v1.DoneableLease;

import java.util.Map;
import java.util.TreeMap;


public class LeaseOperationsImpl extends HasMetadataOperation<Lease, LeaseList, DoneableLease, Resource<Lease, DoneableLease>> {

  public LeaseOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public LeaseOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public LeaseOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("coordination.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("leases"));
    this.type = Lease.class;
    this.listType = LeaseList.class;
    this.doneableType = DoneableLease.class;
  }

  public LeaseOperationsImpl newInstance(OperationContext context) {
    return new LeaseOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.0.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/coordination/v1/LeaseOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.coordination.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.coordination.v1.Lease;
import io.fabric8.kubernetes.api.model.coordination.v1.LeaseBuilder;
import io.fabric8.kubernetes.api.model.coordination.v1.LeaseList;

import java.util.Map;
import java.util.TreeMap;


public class LeaseOperationsImpl extends HasMetadataOperation<Lease, LeaseList, Resource<Lease>> {

  public LeaseOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public LeaseOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public LeaseOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("coordination.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("leases"));
    this.type = Lease.class;
    this.listType = LeaseList.class;
  }

  public LeaseOperationsImpl newInstance(OperationContext context) {
    return new LeaseOperationsImpl(context);
  }

  @Override
  public Lease edit(Visitor... visitors) {
    return patch(new LeaseBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
